@@ -683,7 +683,7 @@ func TestServiceEntryServices(t *testing.T) {
 				krttest.GetMockCollection[*v1.Namespace](mock),
 			)
 			wrapper := builder(krt.TestingDummyContext{}, tt.se)
-			res := slices.Map(wrapper, func(e model.ServiceInfo) *workloadapi.Service {
+			res := slices.Map(wrapper, func(e ServiceEntryInfo) *workloadapi.Service {
 				return e.Service
 			})
 			assert.Equal(t, res, tt.result)
