@@ -29,9 +29,10 @@ func TestTraffic(t *testing.T) {
 	framework.NewTest(t).
 		TopLevel().
 		Run(func(t framework.TestContext) {
-			apps := deployment.NewOrFail(t, deployment.Config{
+			deployments := deployment.NewOrFail(t, deployment.Config{
 				IncludeExtAuthz: false,
 			})
-			common.RunAllTrafficTests(t, i, apps.SingleNamespaceView())
+			SetWaypointServiceEntry(t, "external-service", deployments.NS[0].Namespace.Name(), "waypoint")
+			common.RunAllTrafficTests(t, i, deployments.SingleNamespaceView())
 		})
 }
