@@ -848,9 +848,10 @@ func (cfg *NftablesConfigurator) addIstioTableRules(
 		chain := rule.Chain
 
 		// In IPtables, inserting a rule at position 1 means it gets placed at the head of the chain. In contrast,
-		// nftables starts rule indexing at 0. However, nftables doesn't allow inserting a rule at index 0 if the
-		// chain is empty. So to handle this case, we check if the chain is empty, and if it is, we use appendRule instead.
-		if rule.Index != nil && chainRuleCount[chain] == 0 {
+		// nftables starts rule indexing at 0. However, nftables does not allow inserting a rule at index 0 when
+		// the chain is empty, nor does it allow inserting a rule at position N if the chain already contains N rules.
+		// To handle these cases, we check if the chain is empty and convert it to an append operation.
+		if rule.Index != nil && (chainRuleCount[chain] == 0 || *rule.Index >= chainRuleCount[chain]) {
 			rule.Index = nil
 		}
 
